﻿function Remove-ExcessFile
{
    <#
    .SYNOPSIS
    Командлет предназначен для удаления лишних экземпляров файлов 
    .DESCRIPTION
    -
    .PARAMETER InputCSV
    CSV-файл, полученный в результате выполнения командлета Find-EqualFile
    .PARAMETER IDs
    ID файлов, которые нужно удалить
    .INPUTS
    -
    .OUTPUTS
    -    
    .NOTES
    Версия 1.0 
    (c) 2019 Александр Галков, alexander@galkov.pro
    .EXAMPLE
    Remove-ExcessFile -InputCSV "с:\input.csv" -IDs "5-25,30,50-75,100"
    .LINK
    www.galkov.pro/powershell_script_for_finding_equal_files
    #>

    [CmdletBinding()]
    
    Param
    (
        [Parameter(Mandatory=$true)][string]$InputCSV,
        [Parameter(Mandatory=$true)][string]$IDs
    )

    $all_files = Import-Csv -LiteralPath $InputCSV -Encoding UTF8

    $intervals = @()
    while ($IDs -ne "")
    {
        if ($IDs -match "(.*),(.*)")
        {
            $IDs = $Matches[1]
            $id = $Matches[2]
        }
        else
        {
            $id = $IDs
            $IDs = ""
        }

        $interval = New-Object -TypeName PSObject
        Add-Member -InputObject $interval -MemberType NoteProperty -Name Left -Value 0
        Add-Member -InputObject $interval -MemberType NoteProperty -Name Right -Value 0
        if ($id -match "(.*)-(.*)")
        {
            $interval.Left = [Convert]::ToInt32($Matches[1])
            $interval.Right = [Convert]::ToInt32($Matches[2])
        }
        else
        {
            $interval.Left = $interval.Right = [Convert]::ToInt32($id)
        }
        $intervals += $interval
    }

    $removed_files = @()
    foreach ($file in $all_files)
    {
        foreach ($interval in $intervals)
        {
            if ([Convert]::ToInt32($file.ID) -ge $interval.Left -and [Convert]::ToInt32($file.ID) -le $interval.Right)
            {
	            $removed_files += $file
                break
            }
        }
    }
    $removed_files | Format-Table -AutoSize

    $answer = ""
    while ($answer.ToLower() -ne "y" -and $answer.ToLower() -ne "n")
    {
        $answer = Read-Host -Prompt $("Удалить указанные файлы в количестве {0} шт (y/n)?" -f $removed_files.Length)
    }
    if ($answer.ToLower() -eq "y")
    {
        foreach ($removed_file in $removed_files)
        {
            Remove-Item -LiteralPath $removed_file.Fullname -Force
        }
    }
}